==> spip_3.2.11.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_fr_tu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=fr_tu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Réinitialiser',
	'boxstr_close' => 'Fermer',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Suivant',
	'boxstr_previous' => 'Précédent',
	'boxstr_slideshowStart' => 'Diaporama',
	'boxstr_slideshowStop' => 'Arrêter',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Indique la cible des éléments qui déclencheront la boîte. (Expression CSS ou étendue jQuery)',
	'explication_selecteur_galerie' => 'Indique la cible des éléments à regrouper en galerie. (Expression CSS ou étendue jQuery)',
	'explication_splash_url' => 'Indique l’url du média à afficher automatiquement dans une boîte lors de la première visite sur le site public.',
	'explication_traiter_toutes_images' => 'Insérer une boîte sur toutes les images ?',

	// L
	'label_active' => 'Activer la Boîte Multimédia dans le site public',
	'label_apparence' => 'Apparence',
	'label_aucun_style' => 'N’insérer aucun habillage par défaut',
	'label_choix_transition_elastic' => 'Élastique',
	'label_choix_transition_fade' => 'Fondu enchaîné',
	'label_choix_transition_none' => 'Sans effet de transition',
	'label_maxheight' => 'Hauteur Maxi (% ou px)',
	'label_maxwidth' => 'Largeur Maxi (% ou px)',
	'label_minheight' => 'Hauteur Mini (% ou px)',
	'label_minwidth' => 'Largeur Mini (% ou px)',
	'label_opacite' => 'Opacité du fond',
	'label_selecteur_commun' => 'En général',
	'label_selecteur_galerie' => 'En galerie',
	'label_skin' => 'Habillage visuel',
	'label_slideshow_speed' => 'Temps d’exposition des photos du diaporama (ms)',
	'label_speed' => 'Vitesse de transition (ms)',
	'label_splash' => 'Splash Boîte',
	'label_splash_height' => 'Hauteur (% ou px)',
	'label_splash_url' => 'URL à afficher',
	'label_splash_width' => 'Largeur (% ou px)',
	'label_traiter_toutes_images' => 'Images',
	'label_transition' => 'Transition entre deux affichages',

	// T
	'titre_menu_box' => 'Boîte Multimédia',
	'titre_page_configurer_box' => 'Configuration de la Boîte multimédia'
);

==> spip_4.0.4.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_fr_tu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=fr_tu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Réinitialiser',
	'boxstr_close' => 'Fermer',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'Boite de dialogue',
	'boxstr_dialog_title_medias' => 'Affichage d’un media',
	'boxstr_loading' => 'Chargement…',
	'boxstr_next' => 'Suivant',
	'boxstr_press_escape_to_close' => 'Taper ’Echap’ pour fermer',
	'boxstr_previous' => 'Précédent',
	'boxstr_slideshowStart' => 'Diaporama',
	'boxstr_slideshowStop' => 'Arrêter',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Indique la cible des éléments qui déclencheront la boîte. (Expression CSS ou étendue jQuery)',
	'explication_selecteur_galerie' => 'Indique la cible des éléments à regrouper en galerie. (Expression CSS ou étendue jQuery)',
	'explication_splash_url' => 'Indique l’url du média à afficher automatiquement dans une boîte lors de la première visite sur le site public.',
	'explication_traiter_toutes_images' => 'Insérer une boîte sur toutes les images ?',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'Défaut Noire',
	'info_box_lity_nom_skin__simple_white' => 'Défaut Claire',
	'info_box_lity_nom_skin_fancybox' => 'Façon Fancybox',
	'info_box_lity_nom_skin_thickbox' => 'Façon Thickbox',

	// L
	'label_active' => 'Activer la Boîte Multimédia dans le site public',
	'label_apparence' => 'Apparence',
	'label_aucun_style' => 'N’insérer aucun habillage par défaut',
	'label_choix_transition_elastic' => 'Élastique',
	'label_choix_transition_fade' => 'Fondu enchaîné',
	'label_choix_transition_none' => 'Sans effet de transition',
	'label_maxheight' => 'Hauteur Maxi (% ou px)',
	'label_maxwidth' => 'Largeur Maxi (% ou px)',
	'label_minheight' => 'Hauteur Mini (% ou px)',
	'label_minwidth' => 'Largeur Mini (% ou px)',
	'label_opacite' => 'Opacité du fond',
	'label_selecteur_commun' => 'En général',
	'label_selecteur_galerie' => 'En galerie',
	'label_skin' => 'Habillage visuel',
	'label_slideshow_speed' => 'Temps d’exposition des photos du diaporama (ms)',
	'label_speed' => 'Vitesse de transition (ms)',
	'label_splash' => 'Splash Boîte',
	'label_splash_height' => 'Hauteur (% ou px)',
	'label_splash_url' => 'URL à afficher',
	'label_splash_width' => 'Largeur (% ou px)',
	'label_traiter_toutes_images' => 'Images',
	'label_transition' => 'Transition entre deux affichages',

	// T
	'titre_menu_box' => 'Boîte Multimédia',
	'titre_page_configurer_box' => 'Configuration de la Boîte multimédia'
);
